# -*- coding: utf-8 -*-
from ocyan.core.plugins import OcyanPluginConfig


class HotelWidgetConfig(OcyanPluginConfig):
    def contribute_to_installed_apps(self, installed_apps):
        installed_apps.ocyan.append(
            "ocyan.plugin.hotelwidget"
        )
        return installed_apps
